
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '32.8.6',
    'branch_nick': 'release-32-LTS',
    'revision_id': 'ce0d5e6a899547293697ca2d6b5f6d40467c9d8e',
    'revno': 12667
}
